# ape.types

## Address

```{eval-rst}
.. automodule:: ape.types.address
    :members: AddressType, RawAddress
```

## Signatures

```{eval-rst}
.. autoclass:: ape.types.signatures.SignableMessage
    :members:
    :show-inheritance:
```

```{eval-rst}
.. autoclass:: ape.types.signatures.MessageSignature
    :members:
    :show-inheritance:
```

```{eval-rst}
.. autoclass:: ape.types.signatures.TransactionSignature
    :members:
    :show-inheritance:
```

```{eval-rst}
.. automethod:: ape.types.signatures.recover_signer
```

## Coverage

```{eval-rst}
.. automodule:: ape.types.coverage
    :members:
    :show-inheritance:
```

## Events

```{eval-rst}
.. automodule:: ape.types.events
    :members: ContractLog, ContractLogContainer, MockContractLog, LogFilter
```

## VM

```{eval-rst}
.. automodule:: ape.types.vm
    :members: BlockID, SnapshotID
```

## Gas

```{eval-rst}
.. automodule:: ape.types.gas
    :members: GasLimit, AutoGasLimit
```

## Trace

```{eval-rst}
.. automodule:: ape.types.trace
    :members: GasReport, ControlFlow, SourceTraceback
```

## Units

```{eval-rst}
.. automodule:: ape.types.units
    :members: CurrencyValueComparable, CurrencyValue
```

## Basic

```{eval-rst}
.. automodule:: ape.types.basic
    :members: HexInt
```
